@@ -63,6 +63,8 @@ class SecretManagerServiceAsyncClient:
     parse_secret_version_path = staticmethod(
         SecretManagerServiceClient.parse_secret_version_path
     )
+    topic_path = staticmethod(SecretManagerServiceClient.topic_path)
+    parse_topic_path = staticmethod(SecretManagerServiceClient.parse_topic_path)
 
     common_billing_account_path = staticmethod(
         SecretManagerServiceClient.common_billing_account_path
@@ -93,8 +95,36 @@ class SecretManagerServiceAsyncClient:
         SecretManagerServiceClient.parse_common_location_path
     )
 
-    from_service_account_info = SecretManagerServiceClient.from_service_account_info
-    from_service_account_file = SecretManagerServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            SecretManagerServiceAsyncClient: The constructed client.
+        """
+        return SecretManagerServiceClient.from_service_account_info.__func__(SecretManagerServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            SecretManagerServiceAsyncClient: The constructed client.
+        """
+        return SecretManagerServiceClient.from_service_account_file.__func__(SecretManagerServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
     @property
