@@ -16,53 +16,55 @@
 #
 
 from .resources import (
-    Secret,
-    SecretVersion,
-    Replication,
     CustomerManagedEncryption,
-    ReplicationStatus,
     CustomerManagedEncryptionStatus,
+    Replication,
+    ReplicationStatus,
+    Secret,
     SecretPayload,
+    SecretVersion,
+    Topic,
 )
 from .service import (
-    ListSecretsRequest,
-    ListSecretsResponse,
-    CreateSecretRequest,
-    AddSecretVersionRequest,
-    GetSecretRequest,
-    ListSecretVersionsRequest,
-    ListSecretVersionsResponse,
-    GetSecretVersionRequest,
-    UpdateSecretRequest,
     AccessSecretVersionRequest,
     AccessSecretVersionResponse,
+    AddSecretVersionRequest,
+    CreateSecretRequest,
     DeleteSecretRequest,
+    DestroySecretVersionRequest,
     DisableSecretVersionRequest,
     EnableSecretVersionRequest,
-    DestroySecretVersionRequest,
+    GetSecretRequest,
+    GetSecretVersionRequest,
+    ListSecretsRequest,
+    ListSecretsResponse,
+    ListSecretVersionsRequest,
+    ListSecretVersionsResponse,
+    UpdateSecretRequest,
 )
 
 __all__ = (
-    "Secret",
-    "SecretVersion",
-    "Replication",
     "CustomerManagedEncryption",
-    "ReplicationStatus",
     "CustomerManagedEncryptionStatus",
+    "Replication",
+    "ReplicationStatus",
+    "Secret",
     "SecretPayload",
-    "ListSecretsRequest",
-    "ListSecretsResponse",
-    "CreateSecretRequest",
-    "AddSecretVersionRequest",
-    "GetSecretRequest",
-    "ListSecretVersionsRequest",
-    "ListSecretVersionsResponse",
-    "GetSecretVersionRequest",
-    "UpdateSecretRequest",
+    "SecretVersion",
+    "Topic",
     "AccessSecretVersionRequest",
     "AccessSecretVersionResponse",
+    "AddSecretVersionRequest",
+    "CreateSecretRequest",
     "DeleteSecretRequest",
+    "DestroySecretVersionRequest",
     "DisableSecretVersionRequest",
     "EnableSecretVersionRequest",
-    "DestroySecretVersionRequest",
+    "GetSecretRequest",
+    "GetSecretVersionRequest",
+    "ListSecretsRequest",
+    "ListSecretsResponse",
+    "ListSecretVersionsRequest",
+    "ListSecretVersionsResponse",
+    "UpdateSecretRequest",
 )
