@@ -31,6 +31,7 @@ __protobuf__ = proto.module(
         "CustomerManagedEncryption",
         "ReplicationStatus",
         "CustomerManagedEncryptionStatus",
+        "Topic",
         "SecretPayload",
     },
 )
@@ -74,6 +75,11 @@ class Secret(proto.Message):
             ``[\p{Ll}\p{Lo}\p{N}_-]{0,63}``
 
             No more than 64 labels can be assigned to a given resource.
+        topics (Sequence[google.cloud.secretmanager_v1.types.Topic]):
+            Optional. A list of up to 10 Pub/Sub topics
+            to which messages are published when control
+            plane operations are called on the secret or its
+            versions.
         expire_time (google.protobuf.timestamp_pb2.Timestamp):
             Optional. Timestamp in UTC when the
             [Secret][google.cloud.secretmanager.v1.Secret] is scheduled
@@ -92,6 +98,8 @@ class Secret(proto.Message):
 
     labels = proto.MapField(proto.STRING, proto.STRING, number=4)
 
+    topics = proto.RepeatedField(proto.MESSAGE, number=5, message="Topic",)
+
     expire_time = proto.Field(
         proto.MESSAGE, number=6, oneof="expiration", message=timestamp.Timestamp,
     )
@@ -383,6 +391,22 @@ class CustomerManagedEncryptionStatus(proto.Message):
     kms_key_version_name = proto.Field(proto.STRING, number=1)
 
 
+class Topic(proto.Message):
+    r"""A Pub/Sub topic which Secret Manager will publish to when
+    control plane events occur on this secret.
+
+    Attributes:
+        name (str):
+            Required. The resource name of the Pub/Sub topic that will
+            be published to, in the following format:
+            ``projects/*/topics/*``. For publication to succeed, the
+            Secret Manager P4SA must have ``pubsub.publisher``
+            permissions on the topic.
+    """
+
+    name = proto.Field(proto.STRING, number=1)
+
+
 class SecretPayload(proto.Message):
     r"""A secret payload resource in the Secret Manager API. This contains
     the sensitive secret payload that is associated with a
