@@ -143,7 +143,7 @@ class SecretManagerServiceTransport(abc.ABC):
                     maximum=60.0,
                     multiplier=1.3,
                     predicate=retries.if_exception_type(
-                        exceptions.Unknown, exceptions.ServiceUnavailable,
+                        exceptions.ServiceUnavailable, exceptions.Unknown,
                     ),
                 ),
                 default_timeout=60.0,
